#include "TMHistogrammingGlobalFastorMissingBCmod.h"
#include "AliITSRawStreamSPD.h"
#include <TStyle.h>
#include <TPad.h>
#include <TH1F.h>

//_____________________________________________________________________
TMHistogrammingGlobalFastorMissingBCmod::TMHistogrammingGlobalFastorMissingBCmod(Short_t bcmodfour) :
  TMHistogramming(), fBCmodFour(bcmodfour), fTotalExpected(0), fTotalActual(0)
{
  ResetCounters();
  ResetHitChip();

  fTheHisto = new TH1F("FastorMissingAllChips", Form("Ratio of Missing FastOR Signals (Per Chip) - BC mod %i",(UInt_t)fBCmodFour), 1200, -0.5, 1199.5);
  fTheHisto->SetMinimum(0);
  fTheHisto->SetStats(0);
  fTheHisto->SetFillColor(kBlue);
  fTheHisto->GetXaxis()->SetTitle("[Eq*60+hs*10+chip]   chip number");
  fTheHisto->GetYaxis()->SetTitle("Missing Signals / Expected Signals");
  fTheHisto->SetTitleOffset(1.2,"X");
  fTheHisto->SetTitleOffset(1.6,"Y");
}
//_____________________________________________________________________
TMHistogrammingGlobalFastorMissingBCmod::~TMHistogrammingGlobalFastorMissingBCmod() {
  delete fTheHisto;
}
//_____________________________________________________________________
void TMHistogrammingGlobalFastorMissingBCmod::ResetHitChip() {
  for (UInt_t eq=0; eq<20; eq++) {
    for (UInt_t hs=0; hs<6; hs++) {
      for (UInt_t chip=0; chip<10; chip++) {
	fHitChip[eq][hs][chip] = kFALSE;
      }
    }
  }
}
//_____________________________________________________________________
void TMHistogrammingGlobalFastorMissingBCmod::ResetCounters() {
  fTotalExpected = 0;
  fTotalActual = 0;
  for (UInt_t eq=0; eq<20; eq++) {
    for(UInt_t hs=0; hs<6; hs++){
     for(UInt_t chip=0; chip<10;chip++){
      fExpected[ChipNumber(eq,hs,chip)]=0;
      fActual[ChipNumber(eq,hs,chip)]=0;
    }
   }
  }
}
//_____________________________________________________________________
void TMHistogrammingGlobalFastorMissingBCmod::ProcessPixel(UInt_t eq, UInt_t hs, UInt_t chip, UInt_t col, UInt_t row, Short_t bcmod) {
  if(bcmod == fBCmodFour){
    if (fEventAccept) {
      fHitChip[eq][hs][chip]=kTRUE;
    }
   }
}
//_____________________________________________________________________
void TMHistogrammingGlobalFastorMissingBCmod::EndEvent(AliITSRawStreamSPD *str, UInt_t globalEventNumber) {
  if (fEventAccept) {
    for (UInt_t eq=0; eq<20; eq++) {

      for (UInt_t hs=0; hs<6; hs++) {
	for (UInt_t chip=0; chip<10; chip++) {
	  if (fHitChip[eq][hs][chip]) {
	    fTotalExpected++;
	    fExpected[ChipNumber(eq,hs,chip)]++;
	    if (str->GetFastOrSignal(eq,hs,chip)) {
	      fTotalActual++;
	      fActual[ChipNumber(eq,hs,chip)]++;
	    }
            if (fExpected[ChipNumber(eq,hs,chip)]>0) {
              fTheHisto->SetBinContent(ChipNumber(eq,hs,chip)+1, (Float_t)(fExpected[ChipNumber(eq,hs,chip)]-fActual[ChipNumber(eq,hs,chip)]) / fExpected[ChipNumber(eq,hs,chip)]);
            }
	  }
	}
      }
     
    }

    ResetHitChip();

  }

  TMHistogramming::EndEvent(str, globalEventNumber);
}
//_____________________________________________________________________
void TMHistogrammingGlobalFastorMissingBCmod::Draw(TPad *pad) {
  pad->cd();
  pad->SetLeftMargin(0.15);
  pad->SetRightMargin(0.15);
  pad->SetBorderSize(0);
  pad->SetBorderMode(0);

  fTheHisto->Draw();
}
//_____________________________________________________________________
void TMHistogrammingGlobalFastorMissingBCmod::Reset() {
  ResetCounters();
  fTheHisto->Reset();

  TMHistogramming::Reset();
}
//_____________________________________________________________________
UInt_t TMHistogrammingGlobalFastorMissingBCmod::ChipNumber(UInt_t eq, UInt_t hs, UInt_t chip) {
 if(eq <0 || eq >19) return 1200; 
 if(hs <0 || hs >5) return 1200; 
 if(chip <0 || chip > 9) return 1200; 
 
 return eq*60+hs*10+chip; 

}


